@@ -1,17 +1,17 @@
 import torch
 from typing import List, Generator
-from .strategy.base_strategy import BaseStrategy
 from .provider.base_provider import BaseProvider
+from .strategy.base_strategy import BaseStrategy
 
 
 class BacktrackSampler:
     def __init__(
         self,
-        strategy: BaseStrategy,
-        provider: BaseProvider
+        provider: BaseProvider,
+        strategy: BaseStrategy
     ):
-        self.strategy = strategy
         self.provider = provider
+        self.strategy = strategy
 
     @torch.no_grad()
     def generate(
@@ -27,6 +27,7 @@ class BacktrackSampler:
         **kwargs
     ) -> Generator[List[int], None, None]:
 
+        #See in README.md examples of what the prompt should look like.
         input_tokens = self.provider.encode(prompt, add_special_tokens=False)
         continuation_tokens = []
         release_index = 0
@@ -70,7 +71,7 @@ class BacktrackSampler:
             continuation_tokens = self.strategy.backtrack(continuation_tokens)
 
             if (intial_len > len(continuation_tokens)):
-                self.provider.crop_cache(len(continuation_tokens) - intial_len)
+                self.provider.remove_latest_cache(intial_len - len(continuation_tokens))
 
             while release_index < self.strategy.get_keep_index() - 1:
                 yield continuation_tokens[release_index]
