@@ -21,7 +21,7 @@ class BaseProvider(ABC):
         pass
 
     @abstractmethod
-    def crop_cache(self, idx: int) -> None:
+    def remove_latest_cache(self, nr: int) -> None:
         pass
 
     @abstractmethod
